@@ -1,6 +1,6 @@
 from .__stage__ import Stage, __USER_TEXT__, StageType
 from .__agent__ import Agent, MultiAgent
-from .__tool__ import get_value_from_dict_by_multi_name
+from .__tool__ import get_value_from_dict_by_multi_name, compute_by_string
 from .jieba_zh import analyse
 import re
 
@@ -59,7 +59,8 @@ class QAStage(Stage):
         if get_value_from_dict_by_multi_name(d=data, names=__DISSABLE_WELCOME_LABEL__, default=False):
             self.is_first_access = self.disabel_is_first_access
 
-        self.disable_refuse_question = get_value_from_dict_by_multi_name(d=data, names=__DISABLE_REFUSE_LABEL__, default=False)
+        self.disable_refuse_question = get_value_from_dict_by_multi_name(d=data, names=__DISABLE_REFUSE_LABEL__,
+                                                                         default=False)
 
     def __request_similar_api__(self, text, corpus):
         return similar(text, corpus)
@@ -108,7 +109,6 @@ class QAStage(Stage):
 
             kwargs = self.set_default_var(kwargs, __QA_RESPOND_THRESHOLD__, False)
 
-
         return pass_token, kwargs
 
     @staticmethod
@@ -158,7 +158,8 @@ class REStage(Stage):
         self.sys_reply_complete = get_value_from_dict_by_multi_name(d=self.questions,
                                                                     names=__COMPLETE_SAYING_LABELS__)
         self.is_fits = data.get("is_fits", [])
-        if data.get("__DISSABLE_Q1__", False):
+        # if data.get("__DISSABLE_Q1__", False):
+        if get_value_from_dict_by_multi_name(d=data, names=__DISSABLE_WELCOME_LABEL__, default=False):
             self.is_first_access = self.disabel_is_first_access
 
     @staticmethod
@@ -210,25 +211,40 @@ class LibSwitchStage(Stage):
     def find_new_stages(self, kwargs):
         stages_searched = []
         for filter_tuple in self.stages_filter:
-            label, text, stages_label = filter_tuple
+
+            if len(filter_tuple) == 3:
+                label, text, stages_label = filter_tuple
+                symbol = None
+            elif len(filter_tuple) == 4:
+                label, text, stages_label, symbol = filter_tuple
+            else:
+                raise SyntaxError("find_new_stages: filter_tuple format error")
+
             stages_searched.append(stages_label)
             #
             if label == "*" and text is True:
                 return stages_label
 
             #
-            assert not isinstance(label, list) or isinstance(label, type(text)), "切換路線之條件與限定結果的類型不一致，必須保持兩者都是`str` 或是兩者都是`list`"
+            assert not isinstance(label, list) or isinstance(label, type(
+                text)), "切換路線之條件與限定結果的類型不一致，必須保持兩者都是`str` 或是兩者都是`list`"
             if not isinstance(label, list):
                 label, text = [label], [text]
 
             assert len(label) == len(text), "切換路線之條件與限定結果的數量不一致"
 
             #
+            if symbol is None:
+                symbol = ["="] * int(len(text))
+            else:
+                assert len(symbol) == len(text), "變數比較條件與限定結果的數量不一致"
 
+            #
             pass_token = True
-            for l, t in zip(label, text):
-                if self.get_default_var(kwargs, l) != t:
-                    pass_token = False
+            for l, s, t in zip(label, symbol, text):
+                l_var = self.get_default_var(kwargs, l)
+                pass_token = compute_by_string(l_var, s, t)
+
             if pass_token:
                 return stages_label
 
